#
# spec file for package perl-CAM-PDF
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-CAM-PDF
Version:        1.60
Release:        1.1
%define cpan_name CAM-PDF
Summary:        PDF manipulation library
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/CAM-PDF/
Source:         http://www.cpan.org/authors/id/C/CD/CDOLAN/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Crypt::RC4) >= 2.02
BuildRequires:  perl(Module::Build) >= 0.40
BuildRequires:  perl(Text::PDF) >= 0.29
Requires:       perl(Crypt::RC4) >= 2.02
Requires:       perl(Text::PDF) >= 0.29
Recommends:     perl(Test::Memory::Cycle) >= 1.02
Recommends:     perl(Test::Pod)
Recommends:     perl(Test::Pod::Coverage)
%{perl_requires}

%description
This package reads and writes any document that conforms to the PDF
specification generously provided by Adobe at the
http://partners.adobe.com/public/developer/pdf/index_reference.html manpage
(link last checked Oct 2005).

The file format through PDF 1.5 is well-supported, with the exception of
the "linearized" or "optimized" output format, which this module can read
but not write. Many specific aspects of the document model are not
manipulable with this package (like fonts), but if the input document is
correctly written, then this module will preserve the model integrity.

The PDF writing feature saves as PDF 1.4-compatible. That means that we
cannot write compressed object streams. The consequence is that reading and
then writing a PDF 1.5+ document may enlarge the resulting file by a fair
margin.

This library grants you some power over the PDF security model. Note that
applications editing PDF documents via this library MUST respect the
security preferences of the document. Any violation of this respect is
contrary to Adobe's intellectual property position, as stated in the
reference manual at the above URL.

Technical detail regarding corrupt PDFs: This library adheres strictly to
the PDF specification. Adobe's Acrobat Reader is more lenient, allowing
some corrupted PDFs to be viewable. Therefore, it is possible that some
PDFs may be readable by Acrobat that are illegible to this library. In
particular, files which have had line endings converted to or from
DOS/Windows style (i.e. CR-NL) may be rendered unusable even though Acrobat
does not complain. Future library versions may relax the parser, but not
yet.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc CHANGES LICENSE README

%changelog
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.60
  see /usr/share/doc/packages/perl-CAM-PDF/CHANGES
  1.60  14 Aug 2013
    [ENHANCEMENTS]
  - Added min/max font size for form field filling.
    Thanks to Gareth Tunley for the idea and the initial code
  1.59  28 Jan 2013
    [FIXES]
  - Added support for the \134 escape, synonymous with \
    Thanks to Zakariyya Mughal for the patch
    https://rt.cpan.org/Ticket/Display.html?id=83018
  1.58  28 May 2012
    Many thanks for Vadim Repin for numerous excellent bug reports!
    [FIXES]
  - Appended pdf revisions incorrectly incremented object generation numbers
    https://rt.cpan.org/Ticket/Display.html?id=76513
  - Appending pdf revisions was broken for non-linearized PDFs
    https://rt.cpan.org/Ticket/Display.html?id=76514
  - Allow multiple "startxref" statements in the last 1024 bytes -- unlikely, but possible
    https://rt.cpan.org/Ticket/Display.html?id=77508
  - Allow whitespace at the beginning of an indirect object (I think the PDF spec is
    ambiguous about this)
    https://rt.cpan.org/Ticket/Display.html?id=76512
  - Allow backspace character
    https://rt.cpan.org/Ticket/Display.html?id=76151
    [DOCUMENTATION]
  - mention $pdf->setPageContent($pagenum, $tree->toString());
    Leo Lapworth and http://cpanforum.com/posts/13228
  1.57  17 Dec 2011
    [FIXES]
  - Test for undef streams instead of truth, to allow streams like '' or '0'
    Thanks to Thorsten Schwander for the patch
  - Failed to parse PDF 1.5 cross reference streams where a
    1024-byte boundary happened to fall between "endstream" and
    "endobj" do to a logic error.
    Thanks to Thorsten Schwander for the report and fix suggestion
  1.56  13 Dec 2011
    [FIXES]
  - Workaround for corrupt PDFs that have 'n' records in their index that point to byte zero
    of the file. Silently treat those as 'f' records. Yet another case of Acrobat supporting
    broken PDFs, so the rest of us have to support them too...
    Thanks to Mark Hunnibell for a sample PDF that demonstrated the problem
* Thu Oct  6 2011 jw@suse.com
- update to 1.55,
  1.52 ignored CharMaps.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Jul 26 2010 pascal.bleser@opensuse.org
- initial package (1.52)
